%Master Script file for FLIP package
%Alter values in "Parameter Input" section, then save file and run from
%Matlab command prompt.
%See FLIP user guide for explanation of input parameters

%*************** PARAMETER INPUT SECTION ******************************
nX=215;
nY=94;
Tsplit=240;
Tgrowth=80;
Tmass=60;
N0X=150;
N0Y=150;
Nadd=0;
alpha=0.06;
m=0.001;
Pmass=0.5;

linked=1;
mu=[0.0023	0.0030	0.0012	0.0011	0.0012];

runs=1000;
dispgap=10;
Obs_Rst=0.0039;
Obs_dm2=0.0137;

%*************** RUN FLIP SECTION ******************************
iroot = 2*(nX+nY)-1;
for_Rst=[ones(nX,1) zeros(nX,1); zeros(nY,1) ones(nY,1)];  %used for calculating Rst
V1=zeros(runs,1);     %MS Variance in PopX
V2=zeros(runs,1);     %MS Variance in PopY
dm2=zeros(runs,1);    %delta-mu squared measure
Rst=zeros(runs,1);    %Rst measure
TMRCA=zeros(runs,1);
nloc = length(mu);
for i=1:runs
  if linked==1
    M = fliptree(nX,nY,m,Tsplit,alpha,Tgrowth,N0X,N0Y,Nadd,Tmass,Pmass);
    ms = addmut(M,mu);
  else
    for iloc=1:nloc
      M = fliptree(nX,nY,m,Tsplit,alpha,Tgrowth,N0X,N0Y,Nadd,Tmass,Pmass);
      ms(:,iloc) = addmut(M,mu(iloc));
    end
  end
  V1(i) = mean(diag(cov(ms(1:nX,:))));
  V2(i) = mean(diag(cov(ms(nX+1:nX+nY,:))));
  dm2(i) = mean( (mean(ms(1:nX,:)) - mean(ms(nX+1:nX+nY,:))).^2 );
  Rst(i) = Exc_Rst(for_Rst,ms(1:(nX+nY),:));
  TMRCA(i) = M(iroot,1);
  if  rem(i,dispgap)==0, i, end
end

disp(['Proportion of simulated Rst values <= Obs value (' num2str(Obs_Rst) ') = ' num2str(100*sum(Rst<=Obs_Rst)/runs) '%']);
disp(['Proportion of simulated Rst values >= Obs value (' num2str(Obs_Rst) ') = ' num2str(100*sum(Rst>=Obs_Rst)/runs) '%']);
disp(' ')
disp(['Proportion of simulated d-mu^2 values <= Obs value (' num2str(Obs_dm2) ') = ' num2str(100*sum(dm2<=Obs_dm2)/runs) '%']);
disp(['Proportion of simulated d-mu^2 values >= Obs value (' num2str(Obs_dm2) ') = ' num2str(100*sum(dm2>=Obs_dm2)/runs) '%']);
